/*
Example 2: generated data used to demonstrate 'problems' with the 
simple linear model. All can be fixed with transformations.

X:				predictor
Y1, Y2, Y3:		response variables
*/

data example2;
input X Y1 Y2 Y3;
	lnY1 = log(Y1);			*<--some transformations;
	lnY2 = log(Y2);
	lnY3 = log(Y3);
	srY1 = sqrt(Y1);
	srY2 = sqrt(Y2);
	srY3 = sqrt(Y3);
	lnX  = log(X);
	srX  = sqrt(X);
datalines;
1	2.3		2.4		1.9
2	4.2		3.6		2.5
3	7.6		4.5		3.2
4	14.7	5.8		4.5
5	16.7	5.7		4.2
6	20.3	5.7		4.2
7	23.0	5.5		3.9
8	42.3	7.4		6.7
9	34.9	5.7		4.1
10	65.6	7.5		8.7
1	0.8		1.4		1.4
2	1.1		2.0		1.6
3	4.4		3.5		2.3
4	13.4	5.6		4.1
5	9.1		4.7		2.6
6	26.4	6.7		5.6
7	23.7	5.6		4.0
8	29.8	5.8		4.2
9	38.1	6.2		4.6
10	50.9	6.9		5.6
;


*goptions reset=all;				*<--Control some of the appearance of graphs;
symbol1 v=dot c=blue h=1.4 ;
symbol2 v=none c=red w=3 i=join r=1 line=1;
symbol3 v=none c=black w=1.5 i=join r=2 line=3;	
symbol4 v=none c=blue w=1.5 i=join r=2 line=4;

title 'Regression Workshop (APS 2009). Example 2';

proc gplot data=example2;
title2 'X:Y graph for the first variable (Y1)';
plot Y1*X;
run;

		*ods html;
		*ods graphics on;

proc reg data=example2;
	title2 'OLS: Simple linear regression model, Y1 (with graphs)';
	model Y1 = X / r  cli clm influence ;

	plot Y1*X ;
	plot Y1*X / conf  ;				*<--Observed, predicted, & CI for each X;
	
	plot student.*p.;				*<--Studentized resid. vs predicted;
	plot r.*nqq.;					*<--Normal-quantile plot (look for normality);
									*<--Put some results in SAS file;
	output out=ex2_reg_out p=yhat r=r ucl=ucl lcl=lcl uclm=uclm lclm=lclm;
									*^--Can use stored results for later GPLOT use;
run;
		*ods graphics off;
		*ods html close;
run;

*---Because of problems (see residuals, etc.), try the square-root(Y) transformation...;
proc reg data=example2;
	title2 'OLS: Simple linear regression model, sqrt(Y1)(with graphs)';
	model srY1 = X / r  cli clm influence ;

	plot srY1*X ;
	plot srY1*X / conf  ;			*<--Observed, predicted, & CI for each X;
	
	plot student.*p.;				*<--Studentized resid. vs predicted;
	plot r.*nqq.;					*<--Normal-quantile plot (look for normality);
									*<--Put some results in SAS file;
	*output out=ex2_reg_out p=yhat r=r ucl=ucl lcl=lcl uclm=uclm lclm=lclm;
run;


		*ods graphics off;
		*ods html close;
		run;
/*
*---Look at Y3 response variable as an exercise....;

proc reg data=example2;
	title2 'OLS: Simple linear regression model, Y3 (with graphs)';
	model Y3 = X / r  cli clm influence ;

	plot Y3*X / conf  ;				*<--Observed, predicted, CI, for each X;
	
	plot student.*p.;				*<--Studentized resid. vs predicted;
	plot r.*nqq.;					*<--Normal-quantile plot (look for normality);
									*<--Put some results in SAS file;
	output out=ex2_reg_out p=losshat r=r ucl=ucl lcl=lcl uclm=uclm lclm=lclm;
run;

proc reg data=example2;
	title2 'OLS: Simple linear regression model, lnY3-lnX (with graphs)';
	model lnY3 = lnX / r  cli clm influence ;

	plot lnY3*lnX / conf  ;		*<--Observed, predicted, CI, for each X;
	
	plot student.*p.;				*<--Studentized resid. vs predicted;
	plot r.*nqq.;					*<--Normal-quantile plot (look for normality);
									*<--Put some results in SAS file;
	output out=ex2_reg_out p=losshat r=r ucl=ucl lcl=lcl uclm=uclm lclm=lclm;
run;
*/
run;

